﻿using System.Windows;
using System.Windows.Media;

namespace EafClient.Core
{
	/// <summary>
	/// Extends the DependencyObject class by common reusable methods.
	/// </summary>
	public static class DependencyObjectExtensions
	{
		/// <summary>
		/// Searches the specified source upwards the visual tree for a dependency object of the specified type.
		/// </summary>
		/// <typeparam name="T">The type to search for.</typeparam>
		/// <param name="source">The object to start the search at.</param>
		/// <returns>The found dependency object, if exists. Otherwise null.</returns>
		public static T VisualUpwardSearch<T>(this DependencyObject source) where T : DependencyObject
		{
			while (source != null && source.GetType() != typeof(T))
				source = VisualTreeHelper.GetParent(source);

			return (T)source;
		}
	}
}
